# mypy-boto3-pinpoint

[![PyPI - mypy-boto3-pinpoint](https://img.shields.io/pypi/v/mypy-boto3-pinpoint.svg?color=blue)](https://pypi.org/project/mypy-boto3-pinpoint)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-pinpoint.svg?color=blue)](https://pypi.org/project/mypy-boto3-pinpoint)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.Pinpoint 1.15.11](https://boto3.amazonaws.com/v1/documentation/api/1.15.11/reference/services/pinpoint.html#Pinpoint) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.1.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-pinpoint](#mypy-boto3-pinpoint)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `Pinpoint` service.

```bash
python -m pip install boto3-stubs[pinpoint]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[pinpoint]` in your environment: `python -m pip install 'boto3-stubs[pinpoint]'`

Both type checking and auto-complete should work for `Pinpoint` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[pinpoint]` in your environment: `python -m pip install 'boto3-stubs[pinpoint]'`

Both type checking and auto-complete should work for `Pinpoint` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[pinpoint]` in your environment: `python -m pip install 'boto3-stubs[pinpoint]'`
- Run `mypy` as usual

Type checking should work for `Pinpoint` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[pinpoint]` in your environment: `python -m pip install 'boto3-stubs[pinpoint]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Pinpoint` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`PinpointClient` provides annotations for `boto3.client("pinpoint")`.

```python
import boto3

from mypy_boto3_pinpoint import PinpointClient

client: PinpointClient = boto3.client("pinpoint")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: PinpointClient = session.client("pinpoint")
```








### Typed dictionations

`mypy_boto3_pinpoint.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_pinpoint.type_defs import (
    ActivitiesResponseTypeDef,
    ActivityResponseTypeDef,
    ActivityTypeDef,
    AddressConfigurationTypeDef,
    ADMChannelRequestTypeDef,
    ADMChannelResponseTypeDef,
    ADMMessageTypeDef,
    AndroidPushNotificationTemplateTypeDef,
    APNSChannelRequestTypeDef,
    APNSChannelResponseTypeDef,
    APNSMessageTypeDef,
    APNSPushNotificationTemplateTypeDef,
    APNSSandboxChannelRequestTypeDef,
    APNSSandboxChannelResponseTypeDef,
    APNSVoipChannelRequestTypeDef,
    APNSVoipChannelResponseTypeDef,
    APNSVoipSandboxChannelRequestTypeDef,
    APNSVoipSandboxChannelResponseTypeDef,
    ApplicationDateRangeKpiResponseTypeDef,
    ApplicationResponseTypeDef,
    ApplicationSettingsResourceTypeDef,
    ApplicationsResponseTypeDef,
    AttributeDimensionTypeDef,
    AttributesResourceTypeDef,
    BaiduChannelRequestTypeDef,
    BaiduChannelResponseTypeDef,
    BaiduMessageTypeDef,
    BaseKpiResultTypeDef,
    CampaignCustomMessageTypeDef,
    CampaignDateRangeKpiResponseTypeDef,
    CampaignEmailMessageTypeDef,
    CampaignEventFilterTypeDef,
    CampaignHookTypeDef,
    CampaignLimitsTypeDef,
    CampaignResponseTypeDef,
    CampaignSmsMessageTypeDef,
    CampaignsResponseTypeDef,
    CampaignStateTypeDef,
    ChannelResponseTypeDef,
    ChannelsResponseTypeDef,
    ConditionalSplitActivityTypeDef,
    ConditionTypeDef,
    CreateApplicationRequestTypeDef,
    CreateAppResponseTypeDef,
    CreateCampaignResponseTypeDef,
    CreateEmailTemplateResponseTypeDef,
    CreateExportJobResponseTypeDef,
    CreateImportJobResponseTypeDef,
    CreateJourneyResponseTypeDef,
    CreatePushTemplateResponseTypeDef,
    CreateRecommenderConfigurationResponseTypeDef,
    CreateRecommenderConfigurationTypeDef,
    CreateSegmentResponseTypeDef,
    CreateSmsTemplateResponseTypeDef,
    CreateTemplateMessageBodyTypeDef,
    CreateVoiceTemplateResponseTypeDef,
    CustomDeliveryConfigurationTypeDef,
    CustomMessageActivityTypeDef,
    DefaultMessageTypeDef,
    DefaultPushNotificationMessageTypeDef,
    DefaultPushNotificationTemplateTypeDef,
    DeleteAdmChannelResponseTypeDef,
    DeleteApnsChannelResponseTypeDef,
    DeleteApnsSandboxChannelResponseTypeDef,
    DeleteApnsVoipChannelResponseTypeDef,
    DeleteApnsVoipSandboxChannelResponseTypeDef,
    DeleteAppResponseTypeDef,
    DeleteBaiduChannelResponseTypeDef,
    DeleteCampaignResponseTypeDef,
    DeleteEmailChannelResponseTypeDef,
    DeleteEmailTemplateResponseTypeDef,
    DeleteEndpointResponseTypeDef,
    DeleteEventStreamResponseTypeDef,
    DeleteGcmChannelResponseTypeDef,
    DeleteJourneyResponseTypeDef,
    DeletePushTemplateResponseTypeDef,
    DeleteRecommenderConfigurationResponseTypeDef,
    DeleteSegmentResponseTypeDef,
    DeleteSmsChannelResponseTypeDef,
    DeleteSmsTemplateResponseTypeDef,
    DeleteUserEndpointsResponseTypeDef,
    DeleteVoiceChannelResponseTypeDef,
    DeleteVoiceTemplateResponseTypeDef,
    DirectMessageConfigurationTypeDef,
    EmailChannelRequestTypeDef,
    EmailChannelResponseTypeDef,
    EmailMessageActivityTypeDef,
    EmailMessageTypeDef,
    EmailTemplateRequestTypeDef,
    EmailTemplateResponseTypeDef,
    EndpointBatchItemTypeDef,
    EndpointBatchRequestTypeDef,
    EndpointDemographicTypeDef,
    EndpointItemResponseTypeDef,
    EndpointLocationTypeDef,
    EndpointMessageResultTypeDef,
    EndpointRequestTypeDef,
    EndpointResponseTypeDef,
    EndpointSendConfigurationTypeDef,
    EndpointsResponseTypeDef,
    EndpointUserTypeDef,
    EventConditionTypeDef,
    EventDimensionsTypeDef,
    EventFilterTypeDef,
    EventItemResponseTypeDef,
    EventsBatchTypeDef,
    EventsRequestTypeDef,
    EventsResponseTypeDef,
    EventStartConditionTypeDef,
    EventStreamTypeDef,
    EventTypeDef,
    ExportJobRequestTypeDef,
    ExportJobResourceTypeDef,
    ExportJobResponseTypeDef,
    ExportJobsResponseTypeDef,
    GCMChannelRequestTypeDef,
    GCMChannelResponseTypeDef,
    GCMMessageTypeDef,
    GetAdmChannelResponseTypeDef,
    GetApnsChannelResponseTypeDef,
    GetApnsSandboxChannelResponseTypeDef,
    GetApnsVoipChannelResponseTypeDef,
    GetApnsVoipSandboxChannelResponseTypeDef,
    GetApplicationDateRangeKpiResponseTypeDef,
    GetApplicationSettingsResponseTypeDef,
    GetAppResponseTypeDef,
    GetAppsResponseTypeDef,
    GetBaiduChannelResponseTypeDef,
    GetCampaignActivitiesResponseTypeDef,
    GetCampaignDateRangeKpiResponseTypeDef,
    GetCampaignResponseTypeDef,
    GetCampaignsResponseTypeDef,
    GetCampaignVersionResponseTypeDef,
    GetCampaignVersionsResponseTypeDef,
    GetChannelsResponseTypeDef,
    GetEmailChannelResponseTypeDef,
    GetEmailTemplateResponseTypeDef,
    GetEndpointResponseTypeDef,
    GetEventStreamResponseTypeDef,
    GetExportJobResponseTypeDef,
    GetExportJobsResponseTypeDef,
    GetGcmChannelResponseTypeDef,
    GetImportJobResponseTypeDef,
    GetImportJobsResponseTypeDef,
    GetJourneyDateRangeKpiResponseTypeDef,
    GetJourneyExecutionActivityMetricsResponseTypeDef,
    GetJourneyExecutionMetricsResponseTypeDef,
    GetJourneyResponseTypeDef,
    GetPushTemplateResponseTypeDef,
    GetRecommenderConfigurationResponseTypeDef,
    GetRecommenderConfigurationsResponseTypeDef,
    GetSegmentExportJobsResponseTypeDef,
    GetSegmentImportJobsResponseTypeDef,
    GetSegmentResponseTypeDef,
    GetSegmentsResponseTypeDef,
    GetSegmentVersionResponseTypeDef,
    GetSegmentVersionsResponseTypeDef,
    GetSmsChannelResponseTypeDef,
    GetSmsTemplateResponseTypeDef,
    GetUserEndpointsResponseTypeDef,
    GetVoiceChannelResponseTypeDef,
    GetVoiceTemplateResponseTypeDef,
    GPSCoordinatesTypeDef,
    GPSPointDimensionTypeDef,
    HoldoutActivityTypeDef,
    ImportJobRequestTypeDef,
    ImportJobResourceTypeDef,
    ImportJobResponseTypeDef,
    ImportJobsResponseTypeDef,
    ItemResponseTypeDef,
    JourneyCustomMessageTypeDef,
    JourneyDateRangeKpiResponseTypeDef,
    JourneyEmailMessageTypeDef,
    JourneyExecutionActivityMetricsResponseTypeDef,
    JourneyExecutionMetricsResponseTypeDef,
    JourneyLimitsTypeDef,
    JourneyPushMessageTypeDef,
    JourneyResponseTypeDef,
    JourneyScheduleTypeDef,
    JourneySMSMessageTypeDef,
    JourneysResponseTypeDef,
    JourneyStateRequestTypeDef,
    ListJourneysResponseTypeDef,
    ListRecommenderConfigurationsResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListTemplatesResponseTypeDef,
    ListTemplateVersionsResponseTypeDef,
    MessageBodyTypeDef,
    MessageConfigurationTypeDef,
    MessageRequestTypeDef,
    MessageResponseTypeDef,
    MessageResultTypeDef,
    MessageTypeDef,
    MetricDimensionTypeDef,
    MultiConditionalBranchTypeDef,
    MultiConditionalSplitActivityTypeDef,
    NumberValidateRequestTypeDef,
    NumberValidateResponseTypeDef,
    PhoneNumberValidateResponseTypeDef,
    PublicEndpointTypeDef,
    PushMessageActivityTypeDef,
    PushNotificationTemplateRequestTypeDef,
    PushNotificationTemplateResponseTypeDef,
    PutEventsResponseTypeDef,
    PutEventStreamResponseTypeDef,
    QuietTimeTypeDef,
    RandomSplitActivityTypeDef,
    RandomSplitEntryTypeDef,
    RawEmailTypeDef,
    RecencyDimensionTypeDef,
    RecommenderConfigurationResponseTypeDef,
    RemoveAttributesResponseTypeDef,
    ResultRowTypeDef,
    ResultRowValueTypeDef,
    ScheduleTypeDef,
    SegmentBehaviorsTypeDef,
    SegmentConditionTypeDef,
    SegmentDemographicsTypeDef,
    SegmentDimensionsTypeDef,
    SegmentGroupListTypeDef,
    SegmentGroupTypeDef,
    SegmentImportResourceTypeDef,
    SegmentLocationTypeDef,
    SegmentReferenceTypeDef,
    SegmentResponseTypeDef,
    SegmentsResponseTypeDef,
    SendMessagesResponseTypeDef,
    SendUsersMessageRequestTypeDef,
    SendUsersMessageResponseTypeDef,
    SendUsersMessagesResponseTypeDef,
    SessionTypeDef,
    SetDimensionTypeDef,
    SimpleConditionTypeDef,
    SimpleEmailPartTypeDef,
    SimpleEmailTypeDef,
    SMSChannelRequestTypeDef,
    SMSChannelResponseTypeDef,
    SMSMessageActivityTypeDef,
    SMSMessageTypeDef,
    SMSTemplateRequestTypeDef,
    SMSTemplateResponseTypeDef,
    StartConditionTypeDef,
    TagsModelTypeDef,
    TemplateActiveVersionRequestTypeDef,
    TemplateConfigurationTypeDef,
    TemplateResponseTypeDef,
    TemplatesResponseTypeDef,
    TemplateTypeDef,
    TemplateVersionResponseTypeDef,
    TemplateVersionsResponseTypeDef,
    TreatmentResourceTypeDef,
    UpdateAdmChannelResponseTypeDef,
    UpdateApnsChannelResponseTypeDef,
    UpdateApnsSandboxChannelResponseTypeDef,
    UpdateApnsVoipChannelResponseTypeDef,
    UpdateApnsVoipSandboxChannelResponseTypeDef,
    UpdateApplicationSettingsResponseTypeDef,
    UpdateAttributesRequestTypeDef,
    UpdateBaiduChannelResponseTypeDef,
    UpdateCampaignResponseTypeDef,
    UpdateEmailChannelResponseTypeDef,
    UpdateEmailTemplateResponseTypeDef,
    UpdateEndpointResponseTypeDef,
    UpdateEndpointsBatchResponseTypeDef,
    UpdateGcmChannelResponseTypeDef,
    UpdateJourneyResponseTypeDef,
    UpdateJourneyStateResponseTypeDef,
    UpdatePushTemplateResponseTypeDef,
    UpdateRecommenderConfigurationResponseTypeDef,
    UpdateRecommenderConfigurationTypeDef,
    UpdateSegmentResponseTypeDef,
    UpdateSmsChannelResponseTypeDef,
    UpdateSmsTemplateResponseTypeDef,
    UpdateTemplateActiveVersionResponseTypeDef,
    UpdateVoiceChannelResponseTypeDef,
    UpdateVoiceTemplateResponseTypeDef,
    VoiceChannelRequestTypeDef,
    VoiceChannelResponseTypeDef,
    VoiceMessageTypeDef,
    VoiceTemplateRequestTypeDef,
    VoiceTemplateResponseTypeDef,
    WaitActivityTypeDef,
    WaitTimeTypeDef,
    WriteApplicationSettingsRequestTypeDef,
    WriteCampaignRequestTypeDef,
    WriteEventStreamTypeDef,
    WriteJourneyRequestTypeDef,
    WriteSegmentRequestTypeDef,
    WriteTreatmentResourceTypeDef,
)

def get_structure() -> ADMChannelResponseTypeDef:
    return {
      ...
    }
```
